@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # Copyright (C) 2009 Michael Bieri                                            #
-# Copyright (C) 2010-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2010-2015 Edward d'Auvergne                                   #
 # Copyright (C) 2014 Troels E. Linnet                                         #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
@@ -562,6 +562,26 @@ class Auto_model_free(Base_analysis):
         # Clean up the relaxation data list object.
         self.relax_data.delete()
 
+        # Destroy the dipole-dipole interaction wizard.
+        if hasattr(self, 'dipole_wizard'):
+            self.dipole_wizard.Destroy()
+            del self.dipole_wizard
+
+        # Destroy the mode selection window.
+        self.mode_win.Destroy()
+        del self.mode_win
+
+        # Destroy the model list windows.
+        self.local_tm_model_field.model_win.Destroy()
+        del self.local_tm_model_field
+        self.mf_model_field.model_win.Destroy()
+        del self.mf_model_field
+
+        # Destroy the missing data dialog, if present.
+        if hasattr(self, 'missing_data'):
+            self.missing_data.Destroy()
+            del self.missing_data
+
 
     def execute(self, event=None):
         """Set up, execute, and process the automatic model-free protocol.
@@ -590,7 +610,7 @@ class Auto_model_free(Base_analysis):
 
         # Missing data.
         if len(missing):
-            Missing_data(missing)
+            self.missing_data = Missing_data(missing)
             return
 
         # Display the relax controller, and go to the end of the log window.
@@ -679,6 +699,10 @@ class Auto_model_free(Base_analysis):
         # Change the cursor to busy.
         wx.BeginBusyCursor()
 
+        # Destroy the dipole-dipole interaction wizard, if it exists.
+        if hasattr(self, 'dipole_wizard'):
+            self.dipole_wizard.Destroy()
+
         # Create the wizard.
         self.dipole_wizard = Wiz_window(parent=self.gui, size_x=1000, size_y=750, title="Dipole-dipole interaction setup")
 
