@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # Copyright (C) 2009-2011 Michael Bieri                                       #
-# Copyright (C) 2010-2013 Edward d'Auvergne                                   #
+# Copyright (C) 2010-2015 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -37,6 +37,7 @@ from gui.analyses.execute import Execute
 from gui.base_classes import Container
 from gui.components.spectrum import Spectra_list
 from gui.filedialog import RelaxDirDialog
+from gui.fonts import font
 from gui.message import error_message, Missing_data
 from gui.string_conv import gui_to_int, gui_to_str, str_to_gui
 from gui.uf_objects import Uf_storage; uf_store = Uf_storage()
@@ -142,6 +143,34 @@ class Auto_rx(Base_analysis):
         wx.CallAfter(self.button_exec_relax.Enable, enable)
 
 
+    def add_buttons(self, box):
+        """Add all of the buttons.
+
+        @param box:     The box element to pack the GUI element into.
+        @type box:      wx.BoxSizer instance
+        """
+
+        # Sizer.
+        sizer = wx.BoxSizer(wx.HORIZONTAL)
+
+        # Isotope type button.
+        self.button_select_model = wx.lib.buttons.ThemedGenBitmapTextButton(self, -1, None, " Exponential curve model")
+        self.button_select_model.SetBitmapLabel(wx.Bitmap(fetch_icon("oxygen.actions.list-add", "22x22"), wx.BITMAP_TYPE_ANY))
+        self.button_select_model.SetFont(font.normal)
+        self.button_select_model.SetSize((-1, 25))
+        self.button_select_model.SetToolTipString("Select the model for the exponential curve via the relax_fit.select_model user function.")
+        self.gui.Bind(wx.EVT_BUTTON, self.select_model, self.button_select_model)
+        sizer.Add(self.button_select_model, 1, wx.ALL|wx.EXPAND, 0)
+
+        # 3 invisible 'buttons' for better button layout.
+        sizer.AddStretchSpacer()
+        sizer.AddStretchSpacer()
+        sizer.AddStretchSpacer()
+
+        # Add the element to the box.
+        box.Add(sizer, 0, wx.ALL|wx.EXPAND, 0)
+
+
     def assemble_data(self):
         """Assemble the data required for the auto-analysis.
 
@@ -218,6 +247,11 @@ class Auto_rx(Base_analysis):
         self.peak_intensity = Spectra_list(gui=self.gui, parent=self, box=box, id=str(self.data_index), fn_add=self.peak_wizard_launch, relax_fit_flag=True)
         box.AddSpacer(10)
 
+        # Add the buttons, with spacing.
+        box.AddSpacer(10)
+        self.add_buttons(box=box)
+        box.AddSpacer(10)
+
         # The optimisation settings.
         self.grid_inc = Spin_ctrl(box, self, text="Grid search increments:", default=21, min=1, max=100, tooltip="This is the number of increments per dimension of the grid search performed prior to numerical optimisation.", width_text=self.width_text, width_button=self.width_button, spacer=self.spacer_horizontal)
         self.mc_sim_num = Spin_ctrl(box, self, text="Monte Carlo simulation number:", default=500, min=1, max=100000, tooltip="This is the number of Monte Carlo simulations performed for error propagation and analysis.  For best results, at least 500 is recommended.", width_text=self.width_text, width_button=self.width_button, spacer=self.spacer_horizontal)
@@ -242,6 +276,16 @@ class Auto_rx(Base_analysis):
         # Clean up the peak intensity object.
         self.peak_intensity.delete()
 
+        # Destroy the peak intensity wizard, if it exists.
+        if hasattr(self, 'peak_wizard'):
+            self.peak_wizard.Destroy()
+            del self.peak_wizard
+
+        # Destroy the missing data dialog, if present.
+        if hasattr(self, 'missing_data'):
+            self.missing_data.Destroy()
+            del self.missing_data
+
 
     def execute(self, event):
         """Set up, execute, and process the automatic Rx analysis.
@@ -270,7 +314,7 @@ class Auto_rx(Base_analysis):
 
         # Missing data.
         if len(missing):
-            Missing_data(missing)
+            self.missing_data = Missing_data(missing)
             return
 
         # Display the relax controller, and go to the end of the log window.
@@ -314,6 +358,10 @@ class Auto_rx(Base_analysis):
         @type event:    wx event
         """
 
+        # Destroy the peak intensity wizard, if it exists.
+        if hasattr(self, 'peak_wizard'):
+            self.peak_wizard.Destroy()
+
         # A new wizard instance.
         self.peak_wizard = Peak_intensity_wizard(relax_fit=True)
 
@@ -345,6 +393,17 @@ class Auto_rx(Base_analysis):
         self.field_results_dir.SetValue(str_to_gui(path))
 
 
+    def select_model(self, event=None):
+        """Launch the relax_fit.select_model user function.
+
+        @keyword event: The wx event.
+        @type event:    wx event
+        """
+
+        # Call the user function.
+        uf_store['relax_fit.select_model'](wx_wizard_modal=True)
+
+
     def sync_ds(self, upload=False):
         """Synchronise the analysis frame and the relax data store, both ways.
 
