@@ -1,7 +1,7 @@
 ###############################################################################
 #                                                                             #
 # Copyright (C) 2009 Michael Bieri                                            #
-# Copyright (C) 2010-2013 Edward d'Auvergne                                   #
+# Copyright (C) 2010-2014 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -675,8 +675,8 @@ class Free_file_format_window(wx.Dialog, Wiz_page):
         @type event:    wx event
         """
 
-        # Destroy the window.
-        self.Destroy()
+        # Close the window.
+        self.Close()
 
 
     def reset(self, event):
@@ -700,5 +700,5 @@ class Free_file_format_window(wx.Dialog, Wiz_page):
         # Execute the base class method.
         self._element.save(event)
 
-        # Destroy the window.
-        self.Destroy()
+        # Close the window.
+        self.Close()
