@@ -2,7 +2,7 @@
 #                                                                             #
 # Copyright (C) 2009-2011 Michael Bieri                                       #
 # Copyright (C) 2010-2014 Edward d'Auvergne                                   #
-# Copyright (C) 2013 Troels E. Linnet                                         #
+# Copyright (C) 2013-2014 Troels E. Linnet                                    #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -415,7 +415,7 @@ class Spectral_error_type_page(Wiz_page):
     # Class variables.
     image_path = WIZARD_IMAGE_PATH + 'spectrum' + sep + 'spectrum_200.png'
     title = "Specify the type of error to be used"
-    main_text = "Please specify from where the peak intensity errors will be obtained.  The is required for the execution of the spectrum.error_analysis user function which will be postponed until after clicking on the 'Execute relax' button at the end of the automatic analysis page.  To understand how the errors will be propagated and analysed, the main parts of the spectrum.error_analysis user function description are given below."
+    main_text = "Please specify from where the peak intensity errors will be obtained.  The is required for the execution of the spectrum.error_analysis user function which you will find as a button in the main spectra list GUI element.  To understand how the errors will be propagated and analysed, the main parts of the spectrum.error_analysis user function description are given below."
     uf_path = ['spectrum', 'error_analysis']
 
     def _on_select(self, event):
