@@ -150,7 +150,7 @@ def is_float_array(arg, name=None, size=None, can_be_none=False, raise_error=Tru
     return True
 
 
-def is_float_matrix(arg, name=None, dim=(3, 3), can_be_none=False, raise_error=True):
+def is_float_matrix(arg, name=None, dim=None, can_be_none=False, none_elements=False, raise_error=True):
     """Test if the argument is a matrix of floats.
 
     @param arg:                         The argument.
@@ -161,6 +161,8 @@ def is_float_matrix(arg, name=None, dim=(3, 3), can_be_none=False, raise_error=T
     @type dim:                          tuple of int
     @keyword can_be_none:               A flag specifying if the argument can be none.
     @type can_be_none:                  bool
+    @keyword none_elements:             A flag which if True allows the list to contain None.
+    @type none_elements:                bool
     @keyword raise_error:               A flag which if True will cause RelaxErrors to be raised.
     @type raise_error:                  bool
     @raise RelaxMatrixFloatError:       If not a matrix of floats (and the raise_error flag is set).
@@ -195,8 +197,14 @@ def is_float_matrix(arg, name=None, dim=(3, 3), can_be_none=False, raise_error=T
     # Loop over the first dimension.
     else:
         for i in range(len(arg)):
+            # Catch None elements.
+            if arg[i] == None:
+                if not none_elements:
+                    fail = True
+                continue
+
             # Fail if not a list.
-            if not isinstance(arg[i], list) and not isinstance(arg, ndarray):
+            if not (isinstance(arg[i], list) or isinstance(arg[i], ndarray)):
                 fail = True
 
             # Fail if not the right dimension.
@@ -407,11 +415,11 @@ def is_int_list(arg, name=None, size=None, can_be_none=False, can_be_empty=False
     if can_be_none and arg == None:
         return True
 
-    # Not a list.
+    # Fail if not a list.
     if not isinstance(arg, list):
         fail = True
 
-    # A list.
+    # Other checks.
     else:
         # Fail size is wrong.
         if size != None and len(arg) != size:
@@ -433,9 +441,10 @@ def is_int_list(arg, name=None, size=None, can_be_none=False, can_be_empty=False
                     if not isinstance(arg[i][j], int):
                         fail = True
 
-            # Check if it is an integer.
-            if not isinstance(arg[i], int):
-                fail = True
+            # Simple list.
+            else:
+                if not isinstance(arg[i], int):
+                    fail = True
 
     # Fail.
     if fail:
