@@ -44,13 +44,13 @@ Links
 More information on the NS CPMG 2-site 3D model can be found in the:
 
     - U{relax wiki<http://wiki.nmr-relax.com/NS_CPMG_2-site_3D>},
-    - U{relax manual<http://www.nmr-relax.com/manual/reduced_NS_2_site_3D_CPMG_model.html>},
+    - U{relax manual<http://www.nmr-relax.com/manual/The_reduced_NS_2_site_3D_CPMG_model.html>},
     - U{relaxation dispersion page of the relax website<http://www.nmr-relax.com/analyses/relaxation_dispersion.html#NS_CPMG_2-site_3D>}.
 
 More information on the NS CPMG 2-site 3D full model can be found in the:
 
     - U{relax wiki<http://wiki.nmr-relax.com/NS_CPMG_2-site_3D_full>},
-    - U{relax manual<http://www.nmr-relax.com/manual/full_NS_2_site_3D_CPMG_model.html>},
+    - U{relax manual<http://www.nmr-relax.com/manual/The_full_NS_2_site_3D_CPMG_model.html>},
     - U{relaxation dispersion page of the relax website<http://www.nmr-relax.com/analyses/relaxation_dispersion.html#NS_CPMG_2-site_3D_full>}.
 """
 
