@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2009-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2009-2013 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -25,11 +25,11 @@
 # Python module imports.
 from math import cos, sin
 from numpy import dot, transpose
+from numpy.linalg import norm
 
 # relax module imports.
 from lib.compat import norm
 from lib.linear_algebra.kronecker_product import transpose_23
-from lib.geometry.rotations import tilt_torsion_to_R
 
 
 def daeg_to_rotational_superoperator(daeg, Rsuper):
@@ -90,7 +90,61 @@ def daeg_to_rotational_superoperator(daeg, Rsuper):
     transpose_23(daeg)
 
 
-def pcs_pivot_motion_full(theta_i, phi_i, sigma_i, r_pivot_atom, r_ln_pivot, A, R_eigen, RT_eigen, Ri_prime):
+def pcs_pivot_motion_full_qr_int(full_in_ref_frame=None, r_pivot_atom=None, r_pivot_atom_rev=None, r_ln_pivot=None, A=None, Ri=None, pcs_theta=None, pcs_theta_err=None, missing_pcs=None):
+    """Calculate the PCS value after a pivoted motion for the isotropic cone model.
+
+    @keyword full_in_ref_frame: An array of flags specifying if the tensor in the reference frame is the full or reduced tensor.
+    @type full_in_ref_frame:    numpy rank-1 array
+    @keyword r_pivot_atom:      The pivot point to atom vector.
+    @type r_pivot_atom:         numpy rank-2, 3D array
+    @keyword r_pivot_atom_rev:  The reversed pivot point to atom vector.
+    @type r_pivot_atom_rev:     numpy rank-2, 3D array
+    @keyword r_ln_pivot:        The lanthanide position to pivot point vector.
+    @type r_ln_pivot:           numpy rank-2, 3D array
+    @keyword A:                 The full alignment tensor of the non-moving domain.
+    @type A:                    numpy rank-2, 3D array
+    @keyword Ri:                The frame-shifted, pre-calculated rotation matrix for state i.
+    @type Ri:                   numpy rank-2, 3D array
+    @keyword pcs_theta:         The storage structure for the back-calculated PCS values.
+    @type pcs_theta:            numpy rank-2 array
+    @keyword pcs_theta_err:     The storage structure for the back-calculated PCS errors.
+    @type pcs_theta_err:        numpy rank-2 array
+    @keyword missing_pcs:       A structure used to indicate which PCS values are missing.
+    @type missing_pcs:          numpy rank-2 array
+    """
+
+    # Pre-calculate all the new vectors.
+    rot_vect = dot(r_pivot_atom, Ri) + r_ln_pivot
+
+    # The vector length (to the 5th power).
+    length = 1.0 / norm(rot_vect, axis=1)**5
+
+    # The reverse vectors and lengths.
+    if min(full_in_ref_frame) == 0:
+        rot_vect_rev = dot(r_pivot_atom_rev, Ri) + r_ln_pivot
+        length_rev = 1.0 / norm(rot_vect_rev, axis=1)**5
+
+    # Loop over the atoms.
+    for j in range(len(r_pivot_atom[:, 0])):
+        # Loop over the alignments.
+        for i in range(len(pcs_theta)):
+            # Skip missing data.
+            if missing_pcs[i, j]:
+                continue
+
+            # The projection.
+            if full_in_ref_frame[i]:
+                proj = dot(rot_vect[j], dot(A[i], rot_vect[j]))
+                length_i = length[j]
+            else:
+                proj = dot(rot_vect_rev[j], dot(A[i], rot_vect_rev[j]))
+                length_i = length_rev[j]
+
+            # The PCS.
+            pcs_theta[i, j] += proj * length_i
+
+
+def pcs_pivot_motion_full_quad_int(theta_i, phi_i, sigma_i, r_pivot_atom, r_ln_pivot, A, R_eigen, RT_eigen, Ri_prime):
     """Calculate the PCS value after a pivoted motion for the isotropic cone model.
 
     @param theta_i:             The half cone opening angle (polar angle).
@@ -153,15 +207,9 @@ def pcs_pivot_motion_full(theta_i, phi_i, sigma_i, r_pivot_atom, r_ln_pivot, A,
     return pcs
 
 
-def pcs_pivot_motion_full_qrint(theta_i=None, phi_i=None, sigma_i=None, full_in_ref_frame=None, r_pivot_atom=None, r_pivot_atom_rev=None, r_ln_pivot=None, A=None, R_eigen=None, RT_eigen=None, Ri_prime=None, pcs_theta=None, pcs_theta_err=None, missing_pcs=None, error_flag=False):
+def pcs_pivot_motion_torsionless_qr_int(full_in_ref_frame=None, r_pivot_atom=None, r_pivot_atom_rev=None, r_ln_pivot=None, A=None, Ri=None, pcs_theta=None, pcs_theta_err=None, missing_pcs=None):
     """Calculate the PCS value after a pivoted motion for the isotropic cone model.
 
-    @keyword theta_i:           The half cone opening angle (polar angle).
-    @type theta_i:              float
-    @keyword phi_i:             The cone azimuthal angle.
-    @type phi_i:                float
-    @keyword sigma_i:           The torsion angle for state i.
-    @type sigma_i:              float
     @keyword full_in_ref_frame: An array of flags specifying if the tensor in the reference frame is the full or reduced tensor.
     @type full_in_ref_frame:    numpy rank-1 array
     @keyword r_pivot_atom:      The pivot point to atom vector.
@@ -172,38 +220,29 @@ def pcs_pivot_motion_full_qrint(theta_i=None, phi_i=None, sigma_i=None, full_in_
     @type r_ln_pivot:           numpy rank-2, 3D array
     @keyword A:                 The full alignment tensor of the non-moving domain.
     @type A:                    numpy rank-2, 3D array
-    @keyword R_eigen:           The eigenframe rotation matrix.
-    @type R_eigen:              numpy rank-2, 3D array
-    @keyword RT_eigen:          The transpose of the eigenframe rotation matrix (for faster calculations).
-    @type RT_eigen:             numpy rank-2, 3D array
-    @keyword Ri_prime:          The empty rotation matrix for the in-frame isotropic cone motion for state i.
-    @type Ri_prime:             numpy rank-2, 3D array
+    @keyword Ri:                The frame-shifted, pre-calculated rotation matrix for state i.
+    @type Ri:                   numpy rank-2, 3D array
     @keyword pcs_theta:         The storage structure for the back-calculated PCS values.
     @type pcs_theta:            numpy rank-2 array
     @keyword pcs_theta_err:     The storage structure for the back-calculated PCS errors.
     @type pcs_theta_err:        numpy rank-2 array
     @keyword missing_pcs:       A structure used to indicate which PCS values are missing.
     @type missing_pcs:          numpy rank-2 array
-    @keyword error_flag:        A flag which if True will cause the PCS errors to be estimated and stored in pcs_theta_err.
-    @type error_flag:           bool
     """
 
-    # The rotation matrix.
-    tilt_torsion_to_R(phi_i, theta_i, sigma_i, Ri_prime)
-
-    # The rotation.
-    R_i = dot(R_eigen, dot(Ri_prime, RT_eigen))
-
-    # Pre-calculate all the new vectors (forwards and reverse).
-    rot_vect_rev = transpose(dot(R_i, r_pivot_atom_rev) + r_ln_pivot)
-    rot_vect = transpose(dot(R_i, r_pivot_atom) + r_ln_pivot)
+    # Pre-calculate all the new vectors.
+    rot_vect = dot(r_pivot_atom, Ri) + r_ln_pivot
 
     # The vector length (to the 5th power).
-    length_rev = 1.0 / norm(rot_vect_rev, axis=1)**5
     length = 1.0 / norm(rot_vect, axis=1)**5
 
+    # The reverse vectors and lengths.
+    if min(full_in_ref_frame) == 0:
+        rot_vect_rev = dot(r_pivot_atom_rev, Ri) + r_ln_pivot
+        length_rev = 1.0 / norm(rot_vect_rev, axis=1)**5
+
     # Loop over the atoms.
-    for j in range(len(r_pivot_atom[0])):
+    for j in range(len(r_pivot_atom[:, 0])):
         # Loop over the alignments.
         for i in range(len(pcs_theta)):
             # Skip missing data.
@@ -221,12 +260,8 @@ def pcs_pivot_motion_full_qrint(theta_i=None, phi_i=None, sigma_i=None, full_in_
             # The PCS.
             pcs_theta[i, j] += proj * length_i
 
-            # The square.
-            if error_flag:
-                pcs_theta_err[i, j] += (proj * length_i)**2
 
-
-def pcs_pivot_motion_torsionless(theta_i, phi_i, r_pivot_atom, r_ln_pivot, A, R_eigen, RT_eigen, Ri_prime):
+def pcs_pivot_motion_torsionless_quad_int(theta_i, phi_i, r_pivot_atom, r_ln_pivot, A, R_eigen, RT_eigen, Ri_prime):
     """Calculate the PCS value after a pivoted motion for the isotropic cone model.
 
     @param theta_i:             The half cone opening angle (polar angle).
@@ -285,91 +320,6 @@ def pcs_pivot_motion_torsionless(theta_i, phi_i, r_pivot_atom, r_ln_pivot, A, R_
     return pcs
 
 
-def pcs_pivot_motion_torsionless_qrint(theta_i=None, phi_i=None, full_in_ref_frame=None, r_pivot_atom=None, r_pivot_atom_rev=None, r_ln_pivot=None, A=None, R_eigen=None, RT_eigen=None, Ri_prime=None, pcs_theta=None, pcs_theta_err=None, missing_pcs=None, error_flag=False):
-    """Calculate the PCS value after a pivoted motion for the isotropic cone model.
-
-    @keyword theta_i:           The half cone opening angle (polar angle).
-    @type theta_i:              float
-    @keyword phi_i:             The cone azimuthal angle.
-    @type phi_i:                float
-    @keyword full_in_ref_frame: An array of flags specifying if the tensor in the reference frame is the full or reduced tensor.
-    @type full_in_ref_frame:    numpy rank-1 array
-    @keyword r_pivot_atom:      The pivot point to atom vector.
-    @type r_pivot_atom:         numpy rank-2, 3D array
-    @keyword r_pivot_atom_rev:  The reversed pivot point to atom vector.
-    @type r_pivot_atom_rev:     numpy rank-2, 3D array
-    @keyword r_ln_pivot:        The lanthanide position to pivot point vector.
-    @type r_ln_pivot:           numpy rank-2, 3D array
-    @keyword A:                 The full alignment tensor of the non-moving domain.
-    @type A:                    numpy rank-2, 3D array
-    @keyword R_eigen:           The eigenframe rotation matrix.
-    @type R_eigen:              numpy rank-2, 3D array
-    @keyword RT_eigen:          The transpose of the eigenframe rotation matrix (for faster calculations).
-    @type RT_eigen:             numpy rank-2, 3D array
-    @keyword Ri_prime:          The empty rotation matrix for the in-frame isotropic cone motion for state i.
-    @type Ri_prime:             numpy rank-2, 3D array
-    @keyword pcs_theta:         The storage structure for the back-calculated PCS values.
-    @type pcs_theta:            numpy rank-2 array
-    @keyword pcs_theta_err:     The storage structure for the back-calculated PCS errors.
-    @type pcs_theta_err:        numpy rank-2 array
-    @keyword missing_pcs:       A structure used to indicate which PCS values are missing.
-    @type missing_pcs:          numpy rank-2 array
-    @keyword error_flag:        A flag which if True will cause the PCS errors to be estimated and stored in pcs_theta_err.
-    @type error_flag:           bool
-    """
-
-    # The rotation matrix.
-    c_theta = cos(theta_i)
-    s_theta = sin(theta_i)
-    c_phi = cos(phi_i)
-    s_phi = sin(phi_i)
-    c_phi_c_theta = c_phi * c_theta
-    s_phi_c_theta = s_phi * c_theta
-    Ri_prime[0, 0] =  c_phi_c_theta*c_phi + s_phi**2
-    Ri_prime[0, 1] =  c_phi_c_theta*s_phi - c_phi*s_phi
-    Ri_prime[0, 2] =  c_phi*s_theta
-    Ri_prime[1, 0] =  s_phi_c_theta*c_phi - c_phi*s_phi
-    Ri_prime[1, 1] =  s_phi_c_theta*s_phi + c_phi**2
-    Ri_prime[1, 2] =  s_phi*s_theta
-    Ri_prime[2, 0] = -s_theta*c_phi
-    Ri_prime[2, 1] = -s_theta*s_phi
-    Ri_prime[2, 2] =  c_theta
-
-    # The rotation.
-    R_i = dot(R_eigen, dot(Ri_prime, RT_eigen))
-
-    # Pre-calculate all the new vectors (forwards and reverse).
-    rot_vect_rev = transpose(dot(R_i, r_pivot_atom_rev) + r_ln_pivot)
-    rot_vect = transpose(dot(R_i, r_pivot_atom) + r_ln_pivot)
-
-    # The vector length (to the 5th power).
-    length_rev = 1.0 / norm(rot_vect_rev, axis=1)**5
-    length = 1.0 / norm(rot_vect, axis=1)**5
-
-    # Loop over the atoms.
-    for j in range(len(r_pivot_atom[0])):
-        # Loop over the alignments.
-        for i in range(len(pcs_theta)):
-            # Skip missing data.
-            if missing_pcs[i, j]:
-                continue
-
-            # The projection.
-            if full_in_ref_frame[i]:
-                proj = dot(rot_vect[j], dot(A[i], rot_vect[j]))
-                length_i = length[j]
-            else:
-                proj = dot(rot_vect_rev[j], dot(A[i], rot_vect_rev[j]))
-                length_i = length_rev[j]
-
-            # The PCS.
-            pcs_theta[i, j] += proj * length_i
-
-            # The square.
-            if error_flag:
-                pcs_theta_err[i, j] += (proj * length_i)**2
-
-
 def reduce_alignment_tensor(D, A, red_tensor):
     """Calculate the reduction in the alignment tensor caused by the Frame Order matrix.
 
@@ -442,20 +392,20 @@ def reduce_alignment_tensor_symmetric(D, A, red_tensor):
     red_tensor[4] = (D[5, 5] + D[7, 5])*A[4]
 
 
-def rotate_daeg(matrix, Rx2_eigen):
+def rotate_daeg(matrix, R_eigen):
     """Rotate the given frame order matrix.
 
     It is assumed that the frame order matrix is in the Kronecker product form.
 
 
-    @param matrix:      The Frame Order matrix, 2nd degree to be populated.
-    @type matrix:       numpy 9D, rank-2 array
-    @param Rx2_eigen:   The Kronecker product of the eigenframe rotation matrix with itself.
-    @type Rx2_eigen:    numpy 9D, rank-2 array
+    @param matrix:      The Frame Order matrix to be populated.  All degrees are handled.
+    @type matrix:       numpy rank-2 array
+    @param R_eigen:     The Kronecker product of the eigenframe rotation matrix with itself.
+    @type R_eigen:      numpy rank-2 array
     """
 
     # Rotate.
-    matrix_rot = dot(Rx2_eigen, dot(matrix, transpose(Rx2_eigen)))
+    matrix_rot = dot(R_eigen, dot(matrix, transpose(R_eigen)))
 
     # Return the matrix.
     return matrix_rot
