@@ -24,7 +24,7 @@
 
 # Python module imports (note that some of these are needed for the eval() function call).
 import numpy
-from numpy import set_printoptions, array, inf, nan, ndarray, zeros
+from numpy import set_printoptions, array, int16, int32, float32, float64, inf, nan, ndarray, zeros
 from re import search
 
 # Modify numpy for better output of numbers and structures.
@@ -163,7 +163,7 @@ def object_to_xml(doc, elem, value=None):
         # The converted dict.
         ieee_obj = {}
         conv = False
-        for key in list(value.keys()):
+        for key in value:
             if lib.check_types.is_float(value[key]):
                 ieee_obj[key] = floatAsByteArray(value[key])
                 conv = True
@@ -178,10 +178,16 @@ def object_to_xml(doc, elem, value=None):
             val_elem.appendChild(doc.createTextNode(repr(ieee_obj)))
 
     # Store matrices of floats as IEEE-754 byte arrays.
-    elif lib.arg_check.is_float_matrix(value, raise_error=False):
+    elif lib.arg_check.is_float_matrix(value, none_elements=True, raise_error=False):
         # The converted list.
         ieee_obj = []
         for i in range(len(value)):
+            # Handle None elements.
+            if value[i] == None:
+                ieee_obj.append(None)
+                continue
+
+            # A normal float list or numpy array.
             ieee_obj.append([])
             for j in range(len(value[i])):
                 ieee_obj[-1].append(floatAsByteArray(value[i][j]))
@@ -272,6 +278,10 @@ def xml_to_object(elem, base_object=None, set_fn=None, file_version=1, blacklist
                             for j in range(len(value[i])):
                                 value[i][j] = packBytesAsPyFloat(ieee_value[i][j])
 
+                        # None values.
+                        elif ieee_value[i] == None:
+                            value[i] = None
+
                         # Normal list.
                         else:
                             value[i] = packBytesAsPyFloat(ieee_value[i])
