@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2003-2013 Edward d'Auvergne                                   #
+# Copyright (C) 2003-2014 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the minfx optimisation library,                        #
 # https://gna.org/projects/minfx                                              #
@@ -27,7 +27,7 @@ This file is part of the U{minfx optimisation library<https://gna.org/projects/m
 """
 
 # Python module imports.
-from numpy import dot, float64, outer, sqrt, zeros
+from numpy import dot, float64, inf, outer, sqrt, zeros
 from re import match
 
 # Minfx module imports.
@@ -412,6 +412,11 @@ class Method_of_multipliers(Min):
             if self.conv_test(self.L_new, self.L, self.dL):
                 break
 
+            # Infinite function value.
+            if self.L_new == inf:
+                self.warning = "Infinite function value encountered, can no longer perform optimisation."
+                break
+
             # Lagrange multiplier update function.
             # The update is given by the following formula:
             #    lambdai_k+1 = max(lambdai_k - ci(xk)/mu, 0)
