@@ -28,7 +28,7 @@ import dep_check
 # Python module imports.
 if dep_check.pymol_module:
     import pymol
-from os import F_OK, access, pardir, sep
+from os import F_OK, access, getcwd, pardir, sep
 PIPE, Popen = None, None
 if dep_check.subprocess_module:
     from subprocess import PIPE, Popen
@@ -40,6 +40,7 @@ from warnings import warn
 from lib.errors import RelaxError, RelaxNoPdbError, RelaxNoSequenceError
 from lib.warnings import RelaxWarning
 from lib.io import delete, file_root, get_file_path, open_read_file, open_write_file, test_binary
+from lib.structure.files import find_pdb_files
 from pipe_control.mol_res_spin import exists_mol_res_spin_data
 from pipe_control.pipes import check_pipe
 from pipe_control.result_files import add_result_file
@@ -285,56 +286,14 @@ def cone_pdb(file=None):
     # Read in the cone PDB file.
     pymol_obj.exec_cmd("load " + file)
 
+    # The object ID.
+    id = file_root(file)
 
     # The cone axes.
-    ################
-
-    # Select the AVE, AXE, and SIM residues.
-    pymol_obj.exec_cmd("select (resn AVE,AXE,SIM)")
-
-    # Show the vector as a stick.
-    pymol_obj.exec_cmd("show stick, 'sele'")
-
-    # Colour it blue.
-    pymol_obj.exec_cmd("color cyan, 'sele'")
-
-    # Select the atom used for labelling.
-    pymol_obj.exec_cmd("select (resn AVE,AXE,SIM and symbol N)")
-
-    # Hide the atom.
-    pymol_obj.exec_cmd("hide ('sele')")
-
-    # Label using the atom name.
-    pymol_obj.exec_cmd("cmd.label(\"sele\",\"name\")")
-
+    represent_cone_axis(id=id)
 
     # The cone object.
-    ##################
-
-    # Select the CON residue.
-    pymol_obj.exec_cmd("select (resn CON,EDG)")
-
-    # Hide everything.
-    pymol_obj.exec_cmd("hide ('sele')")
-
-    # Show as 'sticks'.
-    pymol_obj.exec_cmd("show sticks, 'sele'")
-
-    # Colour it white.
-    pymol_obj.exec_cmd("color white, 'sele'")
-
-    # Shorten the stick width from 0.25 to 0.15.
-    pymol_obj.exec_cmd("set stick_radius,0.15000")
-
-    # Set a bit of transparency.
-    pymol_obj.exec_cmd("set stick_transparency, 0.3")
-
-
-    # Clean up.
-    ###########
-
-    # Remove the selection.
-    pymol_obj.exec_cmd("cmd.delete('sele')")
+    represent_cone_object(id=id)
 
 
 def create_macro(data_type=None, style="classic", colour_start=None, colour_end=None, colour_list=None):
@@ -362,96 +321,124 @@ def create_macro(data_type=None, style="classic", colour_start=None, colour_end=
     return commands
 
 
-def frame_order(ave_pos_file="ave_pos.pdb", rep_file="frame_order.pdb", dist_file="domain_distribution.pdb", dir=None):
-    """Display the frame order results (the geometric object, average position and distribution).
+def frame_order(ave_pos="ave_pos", rep="frame_order", sim="simulation.pdb.gz", dir=None):
+    """Display the frame order results (geometric object, average position and Brownian simulation).
 
-    @keyword ave_pos_file:  The name of the file for the average molecule structure.
-    @type ave_pos_file:     str or None
-    @keyword rep_file:      The name of the file of the PDB representation of the frame order dynamics to create.
-    @type rep_file:         str or None
-    @keyword dist_file:     The name of the file which will contain multiple models spanning the full dynamics distribution of the frame order model.
-    @type dist_file:        str or None
-    @keyword dir:           The name of the directory to place the PDB file into.
-    @type dir:              str or None
+    @keyword ave_pos:   The file root of the average molecule structure.
+    @type ave_pos:      str or None
+    @keyword rep:       The file root of the PDB representation of the frame order dynamics to create.
+    @type rep:          str or None
+    @keyword sim:       The full Brownian diffusion file name.
+    @type sim:          str or None
+    @keyword dir:       The name of the directory where the files are located.
+    @type dir:          str or None
     """
 
     # The path.
-    path = ''
+    path = getcwd()
     if dir != None:
         path = dir + sep
 
+    # First disable everything, so that the original domain positions and structures and previous frame order results are not shown by default.
+    pymol_obj.exec_cmd("disable all")
+
     # Set up the respective objects.
-    if ave_pos_file:
-        frame_order_ave_pos(file=path+ave_pos_file)
-    if rep_file:
-        frame_order_geometric(file=path+rep_file)
-    if dist_file:
-        frame_order_distribution(file=path+dist_file)
+    if ave_pos:
+        frame_order_ave_pos(root=ave_pos, path=path)
+    if rep:
+        frame_order_geometric(root=rep, path=path)
+    if sim:
+        frame_order_sim(file=sim, path=path)
+
+    # Centre all objects and zoom.
+    pymol_obj.exec_cmd("center animate=3")
+    pymol_obj.exec_cmd("zoom animate=3")
 
 
-def frame_order_ave_pos(file=None):
+def frame_order_ave_pos(root=None, path=None):
     """Display the PDB structure for the frame order average domain position.
 
-    @keyword file:  The name of the PDB file containing the frame order average structure.
-    @type file:     str
+    @keyword root:  The file root of the PDB file containing the frame order average structure.
+    @type root:     str
     """
 
-    # Read in the PDB file.
-    pymol_obj.exec_cmd("load " + file)
+    # Find all PDB files.
+    pdb_files = find_pdb_files(path=path, file_root=root)
+    pdb_files += find_pdb_files(path=path, file_root=root+'_sim')
 
-    # The object ID.
-    id = file_root(file)
+    # Read in the PDB files.
+    for file in pdb_files:
+        pymol_obj.exec_cmd("load " + file)
+
+        # The object ID.
+        id = file_root(file)
+
+    # Disable the MC simulation representation - the user can find this out for themselves.
+    pymol_obj.exec_cmd("disable %s_sim" % root)
 
 
-def frame_order_distribution(file=None):
-    """Display the PDB structure for the frame order distribution of domain positions.
+def frame_order_sim(file=None, path=None):
+    """Display the PDB structure for the frame order Brownian simulation.
 
-    @keyword file:  The name of the PDB file containing the frame order distribution of domain positions.
-    @type file:     str
+    @keyword root:  The full Brownian diffusion file name.
+    @type root:     str
     """
 
-    # Read in the PDB file.
-    pymol_obj.exec_cmd("load " + file)
+    # Find all PDB files.
+    pdb_files = find_pdb_files(path=path, file_root=file)
+
+    # Read in the PDB files.
+    for file in pdb_files:
+        pymol_obj.exec_cmd("load " + file)
 
 
-
-def frame_order_geometric(file=None):
+def frame_order_geometric(root=None, path=None):
     """Display the frame order geometric object.
 
-    @keyword file:  The name of the PDB file containing the frame order geometric object.
-    @type file:     str
+    @keyword root:  The file root of the PDB file containing the frame order geometric object.
+    @type root:     str
     """
 
-    # Read in the PDB file.
-    pymol_obj.exec_cmd("load " + file)
+    # Find all PDB files.
+    pdb_files = find_pdb_files(path=path, file_root=root)
+    pdb_files += find_pdb_files(path=path, file_root=root+'_A')
+    pdb_files += find_pdb_files(path=path, file_root=root+'_B')
+    pdb_files += find_pdb_files(path=path, file_root=root+'_sim')
+    pdb_files += find_pdb_files(path=path, file_root=root+'_sim_A')
+    pdb_files += find_pdb_files(path=path, file_root=root+'_sim_B')
 
-    # The object ID.
-    id = file_root(file)
+    # Read in the PDB files.
+    for file in pdb_files:
+        # Read in the PDB file.
+        pymol_obj.exec_cmd("load " + file)
 
+        # The object ID.
+        id = file_root(file)
 
-    # Rotor objects.
-    ################
+        # First hide everything.
+        pymol_obj.exec_cmd("select %s" % id)
+        pymol_obj.exec_cmd("hide ('sele')")
+        pymol_obj.exec_cmd("cmd.delete('sele')")
 
-    # Set up the rotor axis (the residues AX and PRC).
-    pymol_obj.exec_cmd("select (resn AX,PRC)")
-    pymol_obj.exec_cmd("show stick, 'sele'")
-    pymol_obj.exec_cmd("color red, 'sele'")
-    pymol_obj.exec_cmd("cmd.delete('sele')")
+        # Set up the titles.
+        represent_titles(id=id)
 
-    # Display the central point.
-    pymol_obj.exec_cmd("select (name CTR)")
-    pymol_obj.exec_cmd("show spheres, 'sele'")
-    pymol_obj.exec_cmd("color red, 'sele'")
-    pymol_obj.exec_cmd("set sphere_scale, 0.3, 'sele'")
-    pymol_obj.exec_cmd("cmd.delete('sele')")
+        # Set up the pivot points.
+        represent_pivots(id=id)
 
-    # Set up the propellers.
-    pymol_obj.exec_cmd("select (resn PRB)")
-    pymol_obj.exec_cmd("show stick, 'sele'")
-    pymol_obj.exec_cmd("set stick_radius, 0.15, 'sele'")
-    pymol_obj.exec_cmd("cmd.delete('sele')")
+        # Set up the rotor objects.
+        represent_rotor_object(id=id)
 
+        # Set up the cone axis.
+        represent_cone_axis(id=id)
 
+        # Set up the cone object.
+        represent_cone_object(id=id)
+
+    # Disable the MC simulation representation - the user can find this out for themselves.
+    pymol_obj.exec_cmd("disable %s_sim" % root)
+    pymol_obj.exec_cmd("disable %s_sim_A" % root)
+    pymol_obj.exec_cmd("disable %s_sim_B" % root)
 
 
 def macro_apply(data_type=None, style="classic", colour_start_name=None, colour_start_rgb=None, colour_end_name=None, colour_end_rgb=None, colour_list=None):
@@ -615,6 +602,177 @@ def macro_write(data_type=None, style="classic", colour_start_name=None, colour_
     add_result_file(type='pymol', label='PyMOL', file=file_path)
 
 
+def represent_cone_axis(id=None):
+    """Set up the PyMOL cone axis representation.
+
+    @keyword id:    The PyMOL object ID.
+    @type id:       str
+    """
+
+    # Sanity check.
+    if id == None:
+        raise RelaxError("The PyMOL object ID must be supplied.")
+
+    # Select the AXE residues.
+    pymol_obj.exec_cmd("select (%s & resn AXE)" % id)
+
+    # Show the vector as a stick.
+    pymol_obj.exec_cmd("show stick, 'sele'")
+
+    # Colour it blue.
+    pymol_obj.exec_cmd("color cyan, 'sele'")
+
+    # Select the atom used for labelling.
+    pymol_obj.exec_cmd("select (%s & resn AXE and symbol N)" % id)
+
+    # Hide the atom.
+    pymol_obj.exec_cmd("hide ('sele')")
+
+    # Label using the atom name.
+    pymol_obj.exec_cmd("cmd.label(\"sele\",\"name\")")
+
+    # Remove the selection.
+    pymol_obj.exec_cmd("cmd.delete('sele')")
+
+
+def represent_cone_object(id=None):
+    """Set up the PyMOL cone object representation.
+
+    @keyword id:    The PyMOL object ID.
+    @type id:       str
+    """
+
+    # Sanity check.
+    if id == None:
+        raise RelaxError("The PyMOL object ID must be supplied.")
+
+    # Select the CON and CNE residues.
+    pymol_obj.exec_cmd("select (%s & resn CON,CNE)" % id)
+
+    # Hide everything.
+    pymol_obj.exec_cmd("hide ('sele')")
+
+    # Show as 'sticks'.
+    pymol_obj.exec_cmd("show sticks, 'sele'")
+
+    # Colour it white.
+    pymol_obj.exec_cmd("color white, 'sele'")
+
+    # Shorten the stick width from 0.25 to 0.15.
+    pymol_obj.exec_cmd("set stick_radius, 0.15, 'sele'")
+
+    # Set a bit of transparency.
+    pymol_obj.exec_cmd("set stick_transparency, 0.3, 'sele'")
+
+    # Remove the selection.
+    pymol_obj.exec_cmd("cmd.delete('sele')")
+
+
+def represent_pivots(id=None):
+    """Set up the PyMOL pivot object representation.
+
+    @keyword id:    The PyMOL object ID.
+    @type id:       str
+    """
+
+    # Sanity check.
+    if id == None:
+        raise RelaxError("The PyMOL object ID must be supplied.")
+
+    # Select the PIV residues.
+    pymol_obj.exec_cmd("select (%s & resn PIV)" % id)
+
+    # Hide the atom.
+    pymol_obj.exec_cmd("hide ('sele')")
+
+    # Label using the atom name.
+    pymol_obj.exec_cmd("cmd.label(\"sele\",\"name\")")
+
+    # Remove the selection.
+    pymol_obj.exec_cmd("cmd.delete('sele')")
+
+
+def represent_titles(id=None):
+    """Set up the PyMOL title object representation.
+
+    @keyword id:    The PyMOL object ID.
+    @type id:       str
+    """
+
+    # Sanity check.
+    if id == None:
+        raise RelaxError("The PyMOL object ID must be supplied.")
+
+    # Frame order representation A.
+    pymol_obj.exec_cmd("select (%s & resn TLE & name a)" % id)
+    pymol_obj.exec_cmd("hide ('sele')")
+    pymol_obj.exec_cmd("label 'sele', 'Representation A'")
+    pymol_obj.exec_cmd("cmd.delete('sele')")
+
+    # Frame order representation B.
+    pymol_obj.exec_cmd("select (%s & resn TLE & name b)" % id)
+    pymol_obj.exec_cmd("hide ('sele')")
+    pymol_obj.exec_cmd("label 'sele', 'Representation B'")
+    pymol_obj.exec_cmd("cmd.delete('sele')")
+
+    # Frame order MC sim representation.
+    pymol_obj.exec_cmd("select (%s & resn TLE & name mc)" % id)
+    pymol_obj.exec_cmd("hide ('sele')")
+    pymol_obj.exec_cmd("label 'sele', 'MC sim representation'")
+    pymol_obj.exec_cmd("cmd.delete('sele')")
+
+    # Frame order MC sim representation A.
+    pymol_obj.exec_cmd("select (%s & resn TLE & name mc-a)" % id)
+    pymol_obj.exec_cmd("hide ('sele')")
+    pymol_obj.exec_cmd("label 'sele', 'MC sim representation A'")
+    pymol_obj.exec_cmd("cmd.delete('sele')")
+
+    # Frame order MC sim representation B.
+    pymol_obj.exec_cmd("select (%s & resn TLE & name mc-b)" % id)
+    pymol_obj.exec_cmd("hide ('sele')")
+    pymol_obj.exec_cmd("label 'sele', 'MC sim representation B'")
+    pymol_obj.exec_cmd("cmd.delete('sele')")
+
+
+def represent_rotor_object(id=None):
+    """Set up the PyMOL rotor object representation.
+
+    @keyword id:    The PyMOL object ID.
+    @type id:       str
+    """
+
+    # Sanity check.
+    if id == None:
+        raise RelaxError("The PyMOL object ID must be supplied.")
+
+    # Rotor objects:  Set up the rotor axis.
+    pymol_obj.exec_cmd("select (%s & resn RTX)" % id)
+    pymol_obj.exec_cmd("show stick, 'sele'")
+    pymol_obj.exec_cmd("color red, 'sele'")
+    pymol_obj.exec_cmd("cmd.delete('sele')")
+
+    # Rotor objects:  Display the central point.
+    pymol_obj.exec_cmd("select (%s & name CTR)" % id)
+    pymol_obj.exec_cmd("show spheres, 'sele'")
+    pymol_obj.exec_cmd("color red, 'sele'")
+    pymol_obj.exec_cmd("set sphere_scale, 0.3, 'sele'")
+    pymol_obj.exec_cmd("cmd.delete('sele')")
+
+    # Rotor objects:  Set up the propellers.
+    pymol_obj.exec_cmd("select (%s & resn RTB)" % id)
+    pymol_obj.exec_cmd("show line, 'sele'")
+    pymol_obj.exec_cmd("cmd.delete('sele')")
+    pymol_obj.exec_cmd("select (%s & resn RTB & name BLD)" % id)
+    pymol_obj.exec_cmd("show spheres, 'sele'")
+    pymol_obj.exec_cmd("set sphere_scale, 0.1, 'sele'")
+    pymol_obj.exec_cmd("cmd.delete('sele')")
+
+    # Rotor objects:  The labels.
+    pymol_obj.exec_cmd("select (%s & resn RTL)" % id)
+    pymol_obj.exec_cmd("cmd.label(\"sele\",\"name\")")
+    pymol_obj.exec_cmd("cmd.delete('sele')")
+
+
 def tensor_pdb(file=None):
     """Display the diffusion tensor geometric structure.
 
