@@ -143,11 +143,8 @@ def bmrb_read(star, sample_conditions=None):
 
     # Get the relaxation data.
     for data in star.relaxation.loop():
-        # Store the keys.
-        keys = list(data.keys())
-
         # Sample conditions do not match (remove the $ sign).
-        if 'sample_cond_list_label' in keys and sample_conditions and data['sample_cond_list_label'].replace('$', '') != sample_conditions:
+        if 'sample_cond_list_label' in data and sample_conditions and data['sample_cond_list_label'].replace('$', '') != sample_conditions:
             continue
 
         # Create the labels.
@@ -200,7 +197,7 @@ def bmrb_read(star, sample_conditions=None):
             errors = [None] * N
 
         # Data transformation.
-        if vals != None and 'units' in keys:
+        if vals != None and 'units' in data:
             # Scaling.
             if data['units'] == 'ms':
                 # Loop over the data.
@@ -321,7 +318,7 @@ def bmrb_write(star):
         used_index = -ones(len(cdp.ri_ids))
         for i in range(len(cdp.ri_ids)):
             # Data exists.
-            if cdp.ri_ids[i] in list(spin.ri_data.keys()):
+            if cdp.ri_ids[i] in spin.ri_data:
                 ri_data_list[i].append(str(spin.ri_data[cdp.ri_ids[i]]))
                 ri_data_err_list[i].append(str(spin.ri_data_err[cdp.ri_ids[i]]))
             else:
@@ -753,63 +750,45 @@ def pack_data(ri_id, ri_type, frq, values, errors, spin_ids=None, mol_names=None
     # Loop over the spin data.
     data = []
     for i in range(N):
+        # A selection union.
+        select_id = spin_ids[i]
+        if spin_id != None:
+            select_id = "%s&%s" % (select_id, spin_id)
+
         # Get the corresponding spin container.
-        match_mol_names, match_res_nums, match_res_names, spins = return_spin_from_selection(spin_ids[i], full_info=True, multi=True)
-        if spins in [None, []]:
-            raise RelaxNoSpinError(spin_ids[i])
+        match_mol_names, match_res_nums, match_res_names, spins = return_spin_from_selection(select_id, full_info=True, multi=True)
 
-        # Remove non-matching spins.
-        if select_obj:
-            new_spins = []
-            new_mol_names = []
-            new_res_nums = []
-            new_res_names = []
-            new_ids = []
-            for j in range(len(spins)):
-                if select_obj.contains_spin(spin_num=spins[j].num, spin_name=spins[j].name, res_num=match_res_nums[j], res_name=match_res_names[j], mol=match_mol_names[j]):
-                    new_spins.append(spins[j])
-                    new_mol_names.append(match_mol_names[j])
-                    new_res_nums.append(match_res_nums[j])
-                    new_res_names.append(match_res_names[j])
-                    new_ids.append(generate_spin_id_unique(mol_name=mol_names[i], res_num=res_nums[i], res_name=res_names[i], spin_num=spins[j].num, spin_name=spins[j].name))
-            new_id = new_ids[0]
-
-        # Aliases for normal operation.
-        else:
-            new_spins = spins
-            new_mol_names = match_mol_names
-            new_res_nums = match_res_nums
-            new_res_names = match_res_names
-            new_id = spin_ids[i]
-            new_ids = None
+        # No spin.
+        if len(spins) == 0:
+            continue
 
         # Check that only a singe spin is present.
-        if len(new_spins) > 1:
-            if new_ids:
-                raise RelaxMultiSpinIDError(spin_ids[i], new_ids)
+        if len(spins) > 1:
+            if ids:
+                raise RelaxMultiSpinIDError(spin_ids[i], ids)
             else:
-                raise RelaxMultiSpinIDError(spin_ids[i], new_ids)
-        if len(new_spins) == 0:
+                raise RelaxMultiSpinIDError(spin_ids[i], ids)
+        if len(spins) == 0:
             raise RelaxNoSpinError(spin_ids[i])
 
         # Loop over the spins.
-        for j in range(len(new_spins)):
+        for j in range(len(spins)):
             # No match to the selection.
-            if select_obj and not select_obj.contains_spin(spin_num=new_spins[j].num, spin_name=new_spins[j].name, res_num=new_res_nums[j], res_name=new_res_names[j], mol=new_mol_names[j]):
+            if select_obj and not select_obj.contains_spin(spin_num=spins[j].num, spin_name=spins[j].name, res_num=res_nums[j], res_name=res_names[j], mol=mol_names[j]):
                 continue
 
             # Initialise the spin data if necessary.
-            if not hasattr(new_spins[j], 'ri_data') or new_spins[j].ri_data == None:
-                new_spins[j].ri_data = {}
-            if not hasattr(new_spins[j], 'ri_data_err') or new_spins[j].ri_data_err == None:
-                new_spins[j].ri_data_err = {}
+            if not hasattr(spins[j], 'ri_data') or spins[j].ri_data == None:
+                spins[j].ri_data = {}
+            if not hasattr(spins[j], 'ri_data_err') or spins[j].ri_data_err == None:
+                spins[j].ri_data_err = {}
 
             # Update all data structures.
-            new_spins[j].ri_data[ri_id] = values[i]
-            new_spins[j].ri_data_err[ri_id] = errors[i]
+            spins[j].ri_data[ri_id] = values[i]
+            spins[j].ri_data_err[ri_id] = errors[i]
 
             # Append the data for printing out.
-            data.append([new_id, repr(values[i]), repr(errors[i])])
+            data.append([spin_ids[i], repr(values[i]), repr(errors[i])])
 
     # Print out.
     if verbose:
@@ -967,16 +946,16 @@ def return_value(spin, data_type, bc=False):
 
     # Relaxation data.
     data = None
-    if not bc and hasattr(spin, 'ri_data') and spin.ri_data != None and data_type in list(spin.ri_data.keys()):
+    if not bc and hasattr(spin, 'ri_data') and spin.ri_data != None and data_type in spin.ri_data:
         data = spin.ri_data[data_type]
 
     # Back calculated relaxation data
-    if bc and hasattr(spin, 'ri_data_bc') and spin.ri_data_bc != None and data_type in list(spin.ri_data_bc.keys()):
+    if bc and hasattr(spin, 'ri_data_bc') and spin.ri_data_bc != None and data_type in spin.ri_data_bc:
         data = spin.ri_data_bc[data_type]
 
     # Relaxation errors.
     error = None
-    if hasattr(spin, 'ri_data_err') and spin.ri_data_err != None and data_type in list(spin.ri_data_err.keys()):
+    if hasattr(spin, 'ri_data_err') and spin.ri_data_err != None and data_type in spin.ri_data_err:
         error = spin.ri_data_err[data_type]
 
     # Return the data.
