@@ -1,6 +1,6 @@
 ###############################################################################
 #                                                                             #
-# Copyright (C) 2009-2014 Edward d'Auvergne                                   #
+# Copyright (C) 2009-2015 Edward d'Auvergne                                   #
 #                                                                             #
 # This file is part of the program relax (http://www.nmr-relax.com).          #
 #                                                                             #
@@ -25,23 +25,27 @@
 # Python module imports.
 from copy import deepcopy
 from math import pi
-from minfx.generic import generic_minimise
-from minfx.grid import grid_point_array
+from minfx.grid import grid_split_array
 from numpy import float64, zeros
-from re import search
+from random import shuffle
+from warnings import warn
 
 # relax module imports.
 from lib.errors import RelaxError, RelaxNoModelError
+from lib.frame_order.variables import MODEL_ISO_CONE_FREE_ROTOR
+from lib.warnings import RelaxWarning
+from multi import Processor_box
 from pipe_control import pipes
 from pipe_control.interatomic import interatomic_loop, return_interatom
 from pipe_control.mol_res_spin import return_spin, spin_loop
-from pipe_control.rdc import check_rdcs
 from specific_analyses.api_base import API_base
 from specific_analyses.api_common import API_common
+from specific_analyses.frame_order.checks import check_pivot
 from specific_analyses.frame_order.data import domain_moving
-from specific_analyses.frame_order.optimisation import grid_row, store_bc_data, target_fn_setup, unpack_opt_results
+from specific_analyses.frame_order.optimisation import Frame_order_grid_command, Frame_order_memo, Frame_order_minimise_command, count_sobol_points, grid_row, store_bc_data, target_fn_data_setup
 from specific_analyses.frame_order.parameter_object import Frame_order_params
 from specific_analyses.frame_order.parameters import assemble_param_vector, linear_constraints, param_num, update_model
+from target_functions import frame_order
 
 
 class Frame_order(API_base, API_common):
@@ -55,10 +59,11 @@ class Frame_order(API_base, API_common):
 
         # Place methods into the API.
         self.deselect = self._deselect_global
+        self.get_model_container = self._get_model_container_cdp
         self.is_spin_param = self._is_spin_param_false
         self.model_loop = self._model_loop_single_global
         self.model_type = self._model_type_global
-        self.overfit_deselect = self._overfit_deselect_dummy
+        self.print_model_title = self._print_model_title_global
         self.return_conversion_factor = self._return_no_conversion_factor
         self.set_param_values = self._set_param_values_global
 
@@ -80,14 +85,19 @@ class Frame_order(API_base, API_common):
 
         # Loop over the interatomic data containers for the moving domain (for the RDC data).
         for interatom in interatomic_loop(selection1=domain_moving()):
-            # RDC checks.
-            if not check_rdcs(interatom):
+            # Skip deselected containers.
+            if not interatom.select:
+                continue
+
+            # No RDC, so skip.
+            if not hasattr(interatom, 'rdc'):
                 continue
 
             # Loop over the alignment IDs.
             for align_id in cdp.rdc_ids:
                 # Yield the info set.
-                yield ['rdc', interatom.spin_id1, interatom.spin_id2, align_id]
+                if align_id in interatom.rdc and interatom.rdc[align_id] != None:
+                    yield ['rdc', interatom.spin_id1, interatom.spin_id2, align_id]
 
         # Loop over the spin containers for the moving domain (for the PCS data).
         for spin, spin_id in spin_loop(selection=domain_moving(), return_id=True):
@@ -102,7 +112,8 @@ class Frame_order(API_base, API_common):
             # Loop over the alignment IDs.
             for align_id in cdp.pcs_ids:
                 # Yield the info set.
-                yield ['pcs', spin_id, align_id]
+                if align_id in spin.pcs and spin.pcs[align_id] != None:
+                    yield ['pcs', spin_id, align_id]
 
 
     def calculate(self, spin_id=None, scaling_matrix=None, verbosity=1, sim_index=None):
@@ -118,20 +129,36 @@ class Frame_order(API_base, API_common):
         @type sim_index:            None or int
         """
 
-        # Set up the target function for direct calculation.
-        model, param_vector = target_fn_setup(sim_index=sim_index, verbosity=verbosity, scaling_matrix=scaling_matrix[0])
+        # Set up the data structures for the target function.
+        param_vector, full_tensors, full_in_ref_frame, rdcs, rdc_err, rdc_weight, rdc_vect, rdc_const, pcs, pcs_err, pcs_weight, atomic_pos, temp, frq, paramag_centre, com, ave_pos_pivot, pivot, pivot_opt = target_fn_data_setup(sim_index=sim_index, verbosity=verbosity, unset_fail=True)
+
+        # The numeric integration information.
+        if not hasattr(cdp, 'quad_int'):
+            cdp.quad_int = False
+        sobol_max_points, sobol_oversample = None, None
+        if hasattr(cdp, 'sobol_max_points'):
+            sobol_max_points = cdp.sobol_max_points
+            sobol_oversample = cdp.sobol_oversample
+
+        # Set up the optimisation target function class.
+        target_fn = frame_order.Frame_order(model=cdp.model, init_params=param_vector, full_tensors=full_tensors, full_in_ref_frame=full_in_ref_frame, rdcs=rdcs, rdc_errors=rdc_err, rdc_weights=rdc_weight, rdc_vect=rdc_vect, dip_const=rdc_const, pcs=pcs, pcs_errors=pcs_err, pcs_weights=pcs_weight, atomic_pos=atomic_pos, temp=temp, frq=frq, paramag_centre=paramag_centre, com=com, ave_pos_pivot=ave_pos_pivot, pivot=pivot, pivot_opt=pivot_opt, sobol_max_points=sobol_max_points, sobol_oversample=sobol_oversample, quad_int=cdp.quad_int)
 
         # Make a single function call.  This will cause back calculation and the data will be stored in the class instance.
-        chi2 = model.func(param_vector)
+        chi2 = target_fn.func(param_vector)
 
         # Set the chi2.
         cdp.chi2 = chi2
 
         # Store the back-calculated data.
-        store_bc_data(model)
+        store_bc_data(A_5D_bc=target_fn.A_5D_bc, pcs_theta=target_fn.pcs_theta, rdc_theta=target_fn.rdc_theta)
+
+        # Feedback on the number of integration points used.
+        if not cdp.quad_int:
+            count_sobol_points(target_fn=target_fn, verbosity=verbosity)
 
         # Printout.
-        print("Chi2:  %s" % chi2)
+        if verbosity:
+            print("Chi2:  %s" % chi2)
 
 
     def constraint_algorithm(self):
@@ -250,15 +277,6 @@ class Frame_order(API_base, API_common):
         else:
             text += "simulation %i." % sim
 
-        # Isotropic order parameter out of range.
-        if name == 'cone_s1' and hasattr(cdp, 'cone_s1'):
-            if cdp.cone_s1 > 1.0:
-                print(text % ("cone S1 order", cdp.cone_s1, "greater", 1.0))
-                return True
-            if cdp.cone_s1 < -0.125:
-                print(text % ("cone S1 order", cdp.cone_s1, "less", -0.125))
-                return True
-
         # Isotropic cone angle out of range.
         if name == 'cone_theta' and hasattr(cdp, 'cone_theta'):
             if cdp.cone_theta >= pi:
@@ -307,7 +325,7 @@ class Frame_order(API_base, API_common):
         """
 
         # First update the model, if needed.
-        update_model()
+        update_model(verbosity=0)
 
         # Return the parameter list object.
         return cdp.params
@@ -351,6 +369,9 @@ class Frame_order(API_base, API_common):
         if not hasattr(cdp, 'model'):
             raise RelaxNoModelError('Frame Order')
 
+        # Test if the pivot has been set.
+        check_pivot()
+
         # The number of parameters.
         n = param_num()
 
@@ -386,7 +407,7 @@ class Frame_order(API_base, API_common):
                 end_point = False
 
             # Append the grid row.
-            row = grid_row(inc[i], lower, upper, dist_type=dist_type, end_point=end_point)
+            row = grid_row(inc[i], lower[i], upper[i], dist_type=dist_type, end_point=end_point)
             grid.append(row)
 
             # Remove an inc if the end point has been removed.
@@ -430,8 +451,55 @@ class Frame_order(API_base, API_common):
                 else:
                     indices[j] = 0
 
-        # Minimisation.
-        self.minimise(min_algor='grid', min_options=pts, scaling_matrix=scaling_matrix, constraints=constraints, verbosity=verbosity, sim_index=sim_index)
+        # Linear constraints.
+        A, b = None, None
+        if constraints:
+            # Obtain the constraints.
+            A, b = linear_constraints(scaling_matrix=scaling_matrix[0])
+
+            # Constraint flag set but no constraints present.
+            if A == None:
+                if verbosity:
+                    warn(RelaxWarning("The '%s' model parameters are not constrained, turning the linear constraint algorithm off." % cdp.model))
+                constraints = False
+
+        # The numeric integration information.
+        if not hasattr(cdp, 'quad_int'):
+            cdp.quad_int = False
+        sobol_max_points, sobol_oversample = None, None
+        if hasattr(cdp, 'sobol_max_points'):
+            sobol_max_points = cdp.sobol_max_points
+            sobol_oversample = cdp.sobol_oversample
+
+        # Set up the data structures for the target function.
+        param_vector, full_tensors, full_in_ref_frame, rdcs, rdc_err, rdc_weight, rdc_vect, rdc_const, pcs, pcs_err, pcs_weight, atomic_pos, temp, frq, paramag_centre, com, ave_pos_pivot, pivot, pivot_opt = target_fn_data_setup(sim_index=sim_index, verbosity=verbosity)
+
+        # Get the Processor box singleton (it contains the Processor instance) and alias the Processor.
+        processor_box = Processor_box() 
+        processor = processor_box.processor
+
+        # Set up for multi-processor execution.
+        if processor.processor_size() > 1:
+            # Printout.
+            print("Parallelised grid search.")
+            print("Randomising the grid points to equalise the time required for each grid subdivision.\n")
+
+            # Randomise the points.
+            shuffle(pts)
+
+        # Loop over each grid subdivision, with all points violating constraints being eliminated.
+        for subdivision in grid_split_array(divisions=processor.processor_size(), points=pts, A=A, b=b, verbosity=verbosity):
+            # Set up the memo for storage on the master.
+            memo = Frame_order_memo(sim_index=sim_index, scaling_matrix=scaling_matrix[0])
+
+            # Set up the command object to send to the slave and execute.
+            command = Frame_order_grid_command(points=subdivision, scaling_matrix=scaling_matrix[0], sim_index=sim_index, model=cdp.model, param_vector=param_vector, full_tensors=full_tensors, full_in_ref_frame=full_in_ref_frame, rdcs=rdcs, rdc_err=rdc_err, rdc_weight=rdc_weight, rdc_vect=rdc_vect, rdc_const=rdc_const, pcs=pcs, pcs_err=pcs_err, pcs_weight=pcs_weight, atomic_pos=atomic_pos, temp=temp, frq=frq, paramag_centre=paramag_centre, com=com, ave_pos_pivot=ave_pos_pivot, pivot=pivot, pivot_opt=pivot_opt, sobol_max_points=sobol_max_points, sobol_oversample=sobol_oversample, verbosity=verbosity, quad_int=cdp.quad_int)
+
+            # Add the slave command and memo to the processor queue.
+            processor.add_to_queue(command, memo)
+
+        # Execute the queued elements.
+        processor.run_queue()
 
 
     def map_bounds(self, param, spin_id=None):
@@ -497,27 +565,37 @@ class Frame_order(API_base, API_common):
         @type inc:                  list of lists of int
         """
 
-        # Set up the target function for direct calculation.
-        model, param_vector = target_fn_setup(sim_index=sim_index, verbosity=verbosity, scaling_matrix=scaling_matrix[0])
+        # Check the optimisation algorithm.
+        algor = min_algor
+        if min_algor == 'Log barrier':
+            algor = min_options[0]
+        allowed = ['simplex']
+        if algor not in allowed:
+            raise RelaxError("Only the 'simplex' minimisation algorithm is supported for the relaxation dispersion analysis as function gradients are not implemented.")
 
-        # Linear constraints.
-        A, b = None, None
-        if constraints:
-            A, b = linear_constraints(scaling_matrix=scaling_matrix[0])
+        # Set up the data structures for the target function.
+        param_vector, full_tensors, full_in_ref_frame, rdcs, rdc_err, rdc_weight, rdc_vect, rdc_const, pcs, pcs_err, pcs_weight, atomic_pos, temp, frq, paramag_centre, com, ave_pos_pivot, pivot, pivot_opt = target_fn_data_setup(sim_index=sim_index, verbosity=verbosity, unset_fail=True)
 
-        # Grid search.
-        if search('^[Gg]rid', min_algor):
-            results = grid_point_array(func=model.func, args=(), points=min_options, verbosity=verbosity)
+        # The numeric integration information.
+        if not hasattr(cdp, 'quad_int'):
+            cdp.quad_int = False
+        sobol_max_points, sobol_oversample = None, None
+        if hasattr(cdp, 'sobol_max_points'):
+            sobol_max_points = cdp.sobol_max_points
+            sobol_oversample = cdp.sobol_oversample
 
-        # Minimisation.
-        else:
-            results = generic_minimise(func=model.func, args=(), x0=param_vector, min_algor=min_algor, min_options=min_options, func_tol=func_tol, grad_tol=grad_tol, maxiter=max_iterations, A=A, b=b, full_output=True, print_flag=verbosity)
+        # Get the Processor box singleton (it contains the Processor instance) and alias the Processor.
+        processor_box = Processor_box() 
+        processor = processor_box.processor
 
-        # Unpack the results.
-        unpack_opt_results(results, scaling_matrix[0], sim_index)
+        # Set up the memo for storage on the master.
+        memo = Frame_order_memo(sim_index=sim_index, scaling_matrix=scaling_matrix[0])
 
-        # Store the back-calculated data.
-        store_bc_data(model)
+        # Set up the command object to send to the slave and execute.
+        command = Frame_order_minimise_command(min_algor=min_algor, min_options=min_options, func_tol=func_tol, grad_tol=grad_tol, max_iterations=max_iterations, scaling_matrix=scaling_matrix[0], constraints=constraints, sim_index=sim_index, model=cdp.model, param_vector=param_vector, full_tensors=full_tensors, full_in_ref_frame=full_in_ref_frame, rdcs=rdcs, rdc_err=rdc_err, rdc_weight=rdc_weight, rdc_vect=rdc_vect, rdc_const=rdc_const, pcs=pcs, pcs_err=pcs_err, pcs_weight=pcs_weight, atomic_pos=atomic_pos, temp=temp, frq=frq, paramag_centre=paramag_centre, com=com, ave_pos_pivot=ave_pos_pivot, pivot=pivot, pivot_opt=pivot_opt, sobol_max_points=sobol_max_points, sobol_oversample=sobol_oversample, verbosity=verbosity, quad_int=cdp.quad_int)
+
+        # Add the slave command and memo to the processor queue.
+        processor.add_to_queue(command, memo)
 
 
     def model_desc(self, model_info=None):
@@ -566,6 +644,38 @@ class Frame_order(API_base, API_common):
         return k, n, cdp.chi2
 
 
+    def overfit_deselect(self, data_check=True, verbose=True):
+        """Deselect spins which have insufficient data to support minimisation.
+
+        @keyword data_check:    A flag to signal if the presence of base data is to be checked for.
+        @type data_check:       bool
+        @keyword verbose:       A flag which if True will allow printouts.
+        @type verbose:          bool
+        """
+
+        # Nothing to do.
+        if not data_check:
+            return
+
+        # Loop over spin data, checking for PCS data.
+        ids = []
+        for spin, spin_id in spin_loop(return_id=True, skip_desel=True):
+            if not hasattr(spin, 'pcs'):
+                spin.select = False
+                ids.append(spin_id)
+        if verbose and len(ids):
+            warn(RelaxWarning("No PCS data is present, deselecting the spins %s." % ids))
+
+        # Loop over the interatomic data containers, checking for RDC data.
+        ids = []
+        for interatom in interatomic_loop(selection1=domain_moving()):
+            if not hasattr(interatom, 'rdc'):
+                interatom.select = False
+                ids.append("%s - %s" % (interatom.spin_id1, interatom.spin_id2))
+        if verbose and len(ids):
+            warn(RelaxWarning("No RDC data is present, deselecting the interatomic data containers between spin pairs %s." % ids))
+
+
     def return_error(self, data_id):
         """Return the RDC or PCS error structure.
 
@@ -650,7 +760,7 @@ class Frame_order(API_base, API_common):
             inc = inc + 1
 
         # Add some additional parameters.
-        if cdp.model == 'iso cone, free rotor' and inc == index:
+        if cdp.model == MODEL_ISO_CONE_FREE_ROTOR and inc == index:
             setattr(cdp, 'cone_theta_err', error)
 
 
@@ -677,34 +787,13 @@ class Frame_order(API_base, API_common):
         model_params = deepcopy(cdp.params)
 
         # Add some additional parameters.
-        if cdp.model == 'iso cone, free rotor':
+        if cdp.model == MODEL_ISO_CONE_FREE_ROTOR:
             param_names.append('cone_theta')
             model_params.append('cone_theta')
 
         # Get the minimisation statistic object names.
         min_names = self.data_names(set='min')
 
-
-        # Test if Monte Carlo parameter values have already been set.
-        #############################################################
-
-        # Loop over all the parameter names.
-        for object_name in param_names:
-            # Not a parameter of the model.
-            if object_name not in model_params:
-                continue
-
-            # Name for the simulation object.
-            sim_object_name = object_name + '_sim'
-
-            # Test if the simulation object already exists.
-            if hasattr(cdp, sim_object_name):
-                raise RelaxError("Monte Carlo parameter values have already been set.")
-
-
-        # Set the Monte Carlo parameter values.
-        #######################################
-
         # Loop over all the data names.
         for object_name in param_names:
             # Not a parameter of the model.
@@ -733,13 +822,16 @@ class Frame_order(API_base, API_common):
             # Create the simulation object.
             setattr(cdp, sim_object_name, [])
 
-            # Get the simulation object.
+            # Get the normal and simulation object.
+            object = None
+            if hasattr(cdp, object_name):
+                object = getattr(cdp, object_name)
             sim_object = getattr(cdp, sim_object_name)
 
             # Loop over the simulations.
             for j in range(cdp.sim_number):
                 # Copy and append the data.
-                sim_object.append(deepcopy(getattr(cdp, object_name)))
+                sim_object.append(deepcopy(object))
 
 
     def sim_pack_data(self, data_id, sim_data):
@@ -817,7 +909,7 @@ class Frame_order(API_base, API_common):
             inc = inc + 1
 
         # Add some additional parameters.
-        if cdp.model == 'iso cone, free rotor' and inc == index:
+        if cdp.model == MODEL_ISO_CONE_FREE_ROTOR and inc == index:
             return getattr(cdp, 'cone_theta_sim')
 
 
