@@ -22,10 +22,20 @@
 # Module docstring.
 """Module for handling the frame order data in the relax data store."""
 
+# Python module imports.
+from numpy import array, float64, zeros
+from warnings import warn
+
 # relax module imports.
 from lib.errors import RelaxError
+from lib.frame_order.variables import MODEL_DOUBLE_ROTOR, MODEL_RIGID
+from lib.warnings import RelaxWarning
+from lib.geometry.rotations import euler_to_R_zyz
+from pipe_control import pipes
 from pipe_control.interatomic import interatomic_loop
 from pipe_control.mol_res_spin import spin_loop
+from pipe_control.pipes import check_pipe
+from specific_analyses.frame_order.checks import check_model, check_pivot
 
 
 def base_data_types():
@@ -77,9 +87,9 @@ def domain_moving():
     if len(cdp.domain) > 2:
         raise RelaxError("Only two domains are supported in the frame order analysis.")
 
-    # Reference domain not set yet, so return nothing.
+    # Reference domain not set yet.
     if not hasattr(cdp, 'ref_domain'):
-        return None
+        raise RelaxError("The reference non-moving domain has not been specified.")
 
     # Loop over the domains.
     for id in cdp.domain:
@@ -91,6 +101,93 @@ def domain_moving():
         return cdp.domain[id]
 
 
+def generate_pivot(order=1, sim_index=None, pipe_name=None, pdb_limit=False):
+    """Create and return the given pivot.
+
+    @keyword order:     The pivot number with 1 corresponding to the first pivot, 2 to the second, etc.
+    @type order:        int
+    @keyword sim_index: The optional Monte Carlo simulation index.  If provided, the pivot for the given simulation will be returned instead.
+    @type sim_index:    None or int
+    @keyword pipe_name: The data pipe 
+    @type pipe_name:    str
+    @keyword pdb_limit: A flag which if True will cause the coordinate to be between -1000 and 1000.
+    @type pdb_limit:    bool
+    @return:            The give pivot point.
+    @rtype:             numpy 3D rank-1 float64 array
+    """
+
+    # Checks.
+    check_pipe(pipe_name)
+    check_pivot(pipe_name=pipe_name)
+    check_model(pipe_name=pipe_name)
+
+    # The data pipe.
+    if pipe_name == None:
+        pipe_name = pipes.cdp_name()
+
+    # Get the data pipe.
+    dp = pipes.get_pipe(pipe_name)
+
+    # Initialise.
+    pivot = None
+
+    # The double rotor parameterisation.
+    if dp.model in [MODEL_DOUBLE_ROTOR]:
+        # The 2nd pivot point (the centre of the frame).
+        if sim_index != None and hasattr(dp, 'pivot_x_sim'):
+            pivot_2nd = array([dp.pivot_x_sim[sim_index], dp.pivot_y_sim[sim_index], dp.pivot_z_sim[sim_index]], float64)
+        else:
+            pivot_2nd = array([dp.pivot_x, dp.pivot_y, dp.pivot_z], float64)
+
+        # Generate the first pivot.
+        if order == 1:
+            # The eigenframe.
+            frame = zeros((3, 3), float64)
+            if sim_index != None and hasattr(dp, 'pivot_disp_sim'):
+                euler_to_R_zyz(dp.eigen_alpha_sim[sim_index], dp.eigen_beta_sim[sim_index], dp.eigen_gamma_sim[sim_index], frame)
+                pivot_disp = dp.pivot_disp_sim[sim_index]
+            else:
+                euler_to_R_zyz(dp.eigen_alpha, dp.eigen_beta, dp.eigen_gamma, frame)
+                pivot_disp = dp.pivot_disp
+
+            # The 1st pivot.
+            pivot = pivot_2nd + frame[:, 2] * pivot_disp
+
+        # Alias the 2nd pivot.
+        elif order == 2:
+            pivot = pivot_2nd
+
+    # All other models.
+    elif order == 1:
+        if sim_index != None and hasattr(dp, 'pivot_x_sim'):
+            pivot = array([dp.pivot_x_sim[sim_index], dp.pivot_y_sim[sim_index], dp.pivot_z_sim[sim_index]], float64)
+        else:
+            pivot = array([dp.pivot_x, dp.pivot_y, dp.pivot_z], float64)
+
+    # PDB limits.
+    if pivot != None and pdb_limit:
+        # The original pivot, as text.
+        orig_pivot = "[%.3f, %.3f, %.3f]" % (pivot[0], pivot[1], pivot[2])
+
+        # Check each coordinate.
+        out = False
+        for i in range(3):
+            if pivot[i] <= -900.0:
+                pivot[i] = -900.0
+                out = True
+            elif pivot[i] > 9900.0:
+                pivot[i] = 9900.0
+                out = True
+
+        # Failure.
+        if out:
+            new_pivot = "[%.3f, %.3f, %.3f]" % (pivot[0], pivot[1], pivot[2])
+            warn(RelaxWarning("The pivot point %s is outside of the PDB coordinate limits of [-999.999, 9999.999], less a 100 Angstrom buffer, shifting to %s." % (orig_pivot, new_pivot)))
+
+    # Return the pivot.
+    return pivot
+
+
 def pivot_fixed():
     """Determine if the pivot is fixed or not.
 
@@ -99,14 +196,16 @@ def pivot_fixed():
     """
 
     # A pivot point is not supported by the model.
-    if cdp.model in ['rigid']:
+    if cdp.model in [MODEL_RIGID]:
         return True
 
-    # The PCS is loaded.
-    if 'pcs' in base_data_types():
-        # The fixed flag is not set.
-        if hasattr(cdp, 'pivot_fixed') and not cdp.pivot_fixed:
-            return False
+    # No PCS data, so the pivot cannot be optimised.
+    if not hasattr(cdp, 'pcs_ids') or len(cdp.pcs_ids) == 0:
+        return True
+
+    # The fixed flag is not set.
+    if hasattr(cdp, 'pivot_fixed') and not cdp.pivot_fixed:
+        return False
 
     # The point is fixed.
     return True
@@ -138,20 +237,3 @@ def tensor_loop(red=False):
     # Loop over the reduction list.
     for i in range(n):
         yield i, data[list[i][index]]
-
-
-def translation_fixed():
-    """Is the translation of the average domain position fixed?
-
-    @return:    The answer to the question.
-    @rtype:     bool
-    """
-
-    # PCS data must be present.
-    if 'pcs' in base_data_types():
-        # The fixed flag is not set.
-        if hasattr(cdp, 'ave_pos_translation') and cdp.ave_pos_translation:
-            return False
-
-    # Default to being fixed.
-    return True
