@@ -16,8 +16,8 @@ from generate_base import Main
 
 class Generate(Main):
     # The number of structures.
-    INC = 0.00036
-    N = int(360 / INC)
+    N = 20000000
+    INC = 360.0 / N
 
     # Cone parameters.
     TILT_ANGLE = 15.0
@@ -34,7 +34,7 @@ class Generate(Main):
         """Set up the rotation for state i."""
 
         # The rotation angle.
-        angle = i * self.INC / 360.0 * 2.0 * pi
+        angle = i * self.INC[motion_index] / 360.0 * 2.0 * pi
 
         # The rotation matrix.
         axis_angle_to_R(self.axes[:, 2], angle, self.R)
