@@ -8,7 +8,6 @@ from numpy.linalg import norm
 from lib.frame_order.rotor_axis import create_rotor_axis_alpha
 from lib.geometry.lines import closest_point_ax
 from lib.geometry.coord_transform import spherical_to_cartesian
-from lib.geometry.rotations import reverse_euler_zyz
 from lib.geometry.vectors import vector_angle
 from pipe_control.structure.mass import pipe_centre_of_mass
 
@@ -44,7 +43,8 @@ def shift_pivot(pivot_orig=None, com=None, axis=None):
 
 
 # The real parameter values.
-AVE_POS_ALPHA, AVE_POS_BETA, AVE_POS_GAMMA = reverse_euler_zyz(4.3434999280669997, 0.43544332764249905, 3.8013235235956007)
+AVE_POS_X, AVE_POS_Y, AVE_POS_Z = [ -21.269217407269576,   -3.122610661328414,   -2.400652421655998]
+AVE_POS_ALPHA, AVE_POS_BETA, AVE_POS_GAMMA = [5.623469076122531, 0.435439405668396, 5.081265529106499]
 AXIS_THETA = 0.69828059079619353433
 AXIS_PHI = 4.03227550621962294031
 CONE_SIGMA_MAX = 30.0 / 360.0 * 2.0 * pi
@@ -89,8 +89,8 @@ for i in range(len(ln)):
 script('../tensors.py')
 
 # Define the domains.
-domain(id='N', spin_id=":1-78")
-domain(id='C', spin_id=":80-148")
+domain(id='N', spin_id="#N-dom")
+domain(id='C', spin_id="#C-dom")
 
 # The tensor domains and reductions.
 full = ['Dy N-dom', 'Tb N-dom', 'Tm N-dom', 'Er N-dom']
@@ -110,9 +110,6 @@ for i in range(len(full)):
 # Select the model.
 frame_order.select_model('rotor')
 
-# Set up the mechanics of the displacement to the average domain position.
-frame_order.average_position(pivot='motional', translation=False)
-
 # Set the reference domain.
 frame_order.ref_domain('N')
 
@@ -123,11 +120,12 @@ frame_order.pivot(pivot, fix=True)
 # Set the paramagnetic centre.
 paramag.centre(pos=[35.934, 12.194, -4.206])
 
-# The optimisation settings.
-frame_order.num_int_pts(num=50)
+# Check the minimum (at a very high quality to check that the chi-squared value is zero).
+frame_order.num_int_pts(num=100000)
 frame_order.quad_int(flag=False)
-
-# Check the minimum.
+value.set(param='ave_pos_x', val=AVE_POS_X)
+value.set(param='ave_pos_y', val=AVE_POS_Y)
+value.set(param='ave_pos_z', val=AVE_POS_Z)
 value.set(param='ave_pos_alpha', val=AVE_POS_ALPHA)
 value.set(param='ave_pos_beta', val=AVE_POS_BETA)
 value.set(param='ave_pos_gamma', val=AVE_POS_GAMMA)
@@ -136,18 +134,35 @@ value.set(param='cone_sigma_max', val=CONE_SIGMA_MAX)
 minimise.calculate()
 
 # Create the PDB representation of the true state.
-frame_order.pdb_model(ave_pos_file=None, rep_file='true_frame_order.pdb', dist_file=None, force=True)
+frame_order.pdb_model(ave_pos='ave_pos_true', rep='frame_order_true', dist=None, compress_type=2, force=True)
 
-# Optimise.
-minimise.grid_search(inc=5)
-minimise.execute('simplex', constraints=True)
+# Save the state.
+state.save('frame_order_true', force=True)
+
+# Grid search (low quality for speed).
+frame_order.num_int_pts(num=200)
+minimise.grid_search(inc=[None, None, None, None, None, None, 21, 21])
+
+# Iterative optimisation with increasing precision.
+num_int_pts = [1000, 10000, 50000]
+func_tol = [1e-2, 1e-3, 1e-4]
+for i in range(len(num_int_pts)):
+    frame_order.num_int_pts(num=num_int_pts[i])
+    minimise.execute('simplex', func_tol=func_tol[i])
 
 # Store the result.
-frame_order.pdb_model(ave_pos_file='ave_pos_fixed_piv.pdb', rep_file='frame_order_fixed_piv.pdb', dist_file=None, force=True)
+frame_order.pdb_model(ave_pos='ave_pos_fixed_piv', rep='frame_order_fixed_piv', dist=None, compress_type=2, force=True)
 
-# Optimise the pivot and model.
+# Save the state.
+state.save('frame_order_fixed_piv', force=True)
+
+# Optimise the pivot and model, again iterating with increasing precision.
 frame_order.pivot(pivot, fix=False)
-minimise.execute('simplex', constraints=True)
+num_int_pts = [1000, 10000, 50000]
+func_tol = [1e-2, 1e-3, 1e-4]
+for i in range(len(num_int_pts)):
+    frame_order.num_int_pts(num=num_int_pts[i])
+    minimise.execute('simplex', func_tol=func_tol[i])
 
 # The distance from the optimised pivot and the rotation axis.
 opt_piv = array([cdp.pivot_x, cdp.pivot_y, cdp.pivot_z])
@@ -161,20 +176,21 @@ print("Original axis:   %s" % AXIS)
 print("Optimised axis:  %s" % opt_axis)
 
 # Test Monte Carlo simulations.
+frame_order.num_int_pts(num=10000)
 monte_carlo.setup(number=5)
 monte_carlo.create_data()
 monte_carlo.initial_values()
-minimise.execute('simplex', constraints=False)
+minimise.execute('simplex', func_tol=1e-2)
 eliminate()
 monte_carlo.error_analysis()
 
 # Create the PDB representation.
-frame_order.pdb_model(force=True)
+frame_order.pdb_model(ave_pos='ave_pos', rep='frame_order', dist=None, compress_type=2, force=True)
+
+# PyMOL.
+pymol.frame_order(ave_pos='ave_pos_true', rep='frame_order_true', dist=None)
+pymol.frame_order(ave_pos='ave_pos_fixed_piv', rep='frame_order_fixed_piv', dist=None)
+pymol.frame_order(ave_pos='ave_pos', rep='frame_order', dist=None)
 
 # Save the state.
 state.save('frame_order', force=True)
-
-# PyMOL.
-pymol.view()
-pymol.command('show spheres')
-pymol.frame_order()
