@@ -198,6 +198,13 @@ uf.add_keyarg(
     can_be_none = True,
     dim = 4
 )
+uf.add_keyarg(
+    name = "create_par_file",
+    default = False,
+    py_type = "bool",
+    desc_short = "creation of file with parameter and calculated chi2",
+    desc = "A flag specifying whether to create a file with parameters and associated chi2 value.  The default of False causes the file not to be created."
+)
 # Description.
 uf.desc.append(Desc_container())
 uf.desc[-1].add_paragraph("This will map the space corresponding to the spin identifier and create the OpenDX files.  The map type can be changed to one of the following supported map types:")
@@ -223,6 +230,6 @@ uf.desc[-1].add_prompt("relax> dx.map(params=['s2', 'te', 'rex'], spin_id=':2@N6
 uf.backend = map
 uf.menu_text = "&map"
 uf.gui_icon = "relax.grid_search"
-uf.wizard_height_desc = 280
+uf.wizard_height_desc = 260
 uf.wizard_size = (1000, 750)
 uf.wizard_image = WIZARD_IMAGE_PATH + 'opendx.png'
